clc;
clear all;
close all;

% Solid disc data
x_solid = [0.2326, 0.5471, 1.0241, 1.5425, 2.1784, 2.6995, 3.2834];  %Damping coefficient values
y = [488, 765, 1022, 1143, 1465, 1778, 2011];  %corresponding field values

% Perforated disc data
x_perfor = [0.0786, 0.1713, 0.2761, 0.4551, 0.5889, 0.8621, 1.0934];  

error_percentage = [1.04, 0.72, 0.75, 0.52,2.43, 2.49, 1.92]; % Field error percentages

% Convert percentage error to absolute flux error
flux_error = (error_percentage ./ 100) .* y; 

% Linear Fit for Solid Disc
p_solid = polyfit(y, x_solid, 1);
x_solid_fit = polyval(p_solid, y); % Compute fitted values

% Linear Fit for Perforated Disc
p_perfor = polyfit(y, x_perfor, 1);
x_perfor_fit = polyval(p_perfor, y);

% Compute Slope (m)
m_solid = p_solid(1);
m_perfor = p_perfor(1);

% Calculate Residual Error (Curve Fit Error)
error_fit_solid = abs(x_solid - x_solid_fit); % Difference from the fitted line
error_fit_perfor = abs(x_perfor - x_perfor_fit);

% Convert Variable Flux Error to Damping Coefficient Error
error_flux_solid = abs(m_solid * flux_error); % Propagated flux error (solid)
error_flux_perfor = abs(m_perfor * flux_error); % Propagated flux error (perforated)

% Combine both errors using Quadratic Summation
error_solid = sqrt(error_fit_solid.^2 + error_flux_solid.^2);
error_perfor = sqrt(error_fit_perfor.^2 + error_flux_perfor.^2);

% Generate a smooth curve for fitted lines
y_fit_solid = linspace(min(y), max(y), 100);
x_fit_solid = polyval(p_solid, y_fit_solid);
y_fit_perfor = linspace(min(y), max(y), 100);
x_fit_perfor = polyval(p_perfor, y_fit_perfor);

% Create the figure
figure;
hold on;

% Plot measured data points
plot(y, x_solid, 'r.', 'MarkerSize', 8, 'LineWidth', 2); % Red points for Solid
plot(y, x_perfor, 'b*', 'MarkerSize', 5, 'LineWidth', 2); % Blue points for Perforated

% Plot fitted lines
plot(y_fit_solid, x_fit_solid, 'r-', 'LineWidth', 2); % Red line for Solid
plot(y_fit_perfor, x_fit_perfor, 'b-', 'LineWidth', 2); % Blue line for Perforated

% Add error bars (Only in X-direction)
errorbar(y, x_solid, error_solid, 'r.', 'MarkerSize', 10, 'CapSize', 8, 'LineWidth', 1.5);
errorbar(y, x_perfor, error_perfor, 'b.', 'MarkerSize', 10, 'CapSize', 8, 'LineWidth', 1.5);

% Labels, Title, and Legend
ylabel('\gamma (s^{-1})');
xlabel('Magnetic field ($\vec B$)', 'Interpreter', 'latex');
title('Damping coefficient vs Magnetic field');
legend('Solid Disc', 'Perforated Disc', 'Location', 'best');
ytickformat('%.1f');
grid on;
hold off;
%% Save figure as a high-resolution image (PNG format, 600 DPI)
saveas(gcf, 'FluxvsSettlingTime.png'); % Save as PNG
print(gcf, 'damp.coeffvsflux.png', '-dpng', '-r600'); % High-resolution 600 DPI