clc;
clear;

% Load data from CSV file
data = readtable('solid_4.csv'); %Replace with your file name

% Extract relevant columns(make sure names in csv file are same as here)
time = data.Time_s;        % Time in seconds
angle = data.Angle_;       % Angle in degrees
flux = data.PhysHall_G;    % Flux in Gauss

% Smooth the angle data to reduce noise
angle_smooth = smoothdata(angle, 'movmean', 6); % Moving average smoothing

% Create a figure with subplots
figure;

% Subplot 1: Flux vs Time
subplot(2, 2, 1);
plot(time, flux, 'r', 'LineWidth', 1);
title('Magnetic field vs Time');
xlabel('Time (s)');
ylabel('Magnetic Field (G)'); % Unit in Gauss
xlim([0, 30]);
ylim([0, 2500]);
yticks([0:300:3000]);
grid on;

% Subplot 2: Angle vs Time (Smoothed)
subplot(2, 2, 2);
plot(time, angle_smooth, 'k', 'LineWidth', 1); % Smoothed curve
title('Angle vs Time');
xlabel('Time (s)');
ylabel('Angle (°)');
grid on;
hold off;

% Find prominent peaks (only the major ones)
[pks, locs] = findpeaks(angle_smooth, time, 'MinPeakProminence', 0.5, 'MinPeakDistance', 0.5);

% Ensure the absolute maximum peak is included
[max_peak, max_index] = max(angle_smooth);
max_time = time(max_index);
pks = [pks; max_peak]; % Add max peak
locs = [locs; max_time]; % Add corresponding time
[pks, sort_idx] = sort(pks, 'descend'); % Sort by peak height
locs = locs(sort_idx); % Keep corresponding times sorted

% Remove duplicate values (if any)
[pks, unique_idx] = unique(pks, 'stable');
locs = locs(unique_idx);

% Subplot 3: Peak Detection with Smoothed Angle
subplot(2, 2, 3);
plot(time, angle_smooth, 'b', 'LineWidth', 1);
hold on;
plot(locs, pks, 'r.', 'MarkerSize', 10, 'LineWidth', 1);
legend('Data', 'Detected Peaks');
title('Peak Detection');
xlabel('Time (s)');
ylabel('Angle (°)');
grid on;
hold off;

% Fit an exponential decay curve to the detected peaks
expFit = fit(locs, pks, 'exp1'); % Fits A = A0 * exp(-bt)

% Extract fitted parameters
A0 = expFit.a;  % Initial amplitude
b = -expFit.b;  % Decay constant (negated because fit() uses A0 * exp(b*t))

% Generate fitted curve values
t_fit = linspace(min(locs), max(locs), 100);
A_fit = A0 * exp(-b * t_fit);

% Subplot 4: Plotting Peaks and Exponential Decay Curve Fit
subplot(2, 2, 4);
plot(locs, pks, 'r.', 'MarkerSize', 10, 'LineWidth', 1); % Peaks
hold on;
plot(t_fit, A_fit, 'g-', 'LineWidth', 1); % Fitted exponential curve
title('Exponential Decay Curve Fit');
xlabel('Time (s)');
ylabel('Value');
grid on;
legend('Detected Peaks', 'Fitted Exp Decay');
hold off;

% Display fitted parameters
disp(['Damping coefficient (b): ', num2str(b)]);
%%
% Save figure as a high-resolution image (PNG format, 600 DPI)
saveas(gcf, 'angle_flux_plot.png'); % Save as PNG
print(gcf, 'solid_4.png', '-dpng', '-r600'); % High-resolution 600 DPI
